==> navigine_sdk-0.0.1.tar.gz: lib/models/device_info.dart <==
part of navigine_sdk;

class DeviceInfo {
  String id = "";
  int location = 0;
  int subLocation = 0;
  int time = 0;
  double x = 0.0;
  double y = 0.0;
  double r = 0.0;
  double azimuth = 0.0;
  double stepLength = 0.0;
  int stepCount = 0;
  int errorCode = 0;
  List<RoutePath> paths = [];
  List<Zone> zones = [];
  double latitude = 0;
  double longitude = 0;

  static DeviceInfo fromMap(data) {
    DeviceInfo di = DeviceInfo();
    di.azimuth = data["azimuth"] as double;
    di.errorCode = data["errorCode"] as int;
    di.id = data["id"] as String;
    di.location = data["location"] as int;
    di.r = data["r"] as double;
    di.stepCount = data["stepCount"] as int;
    di.subLocation = data["subLocation"] as int;
    di.stepLength = data["stepLength"] as double;
    di.time = data["time"] as int;
    di.x = data["x"] as double;
    di.y = data["y"] as double;

    for (var zone in data["zones"]) {
      di.zones.add(Zone.fromMap(zone));
    }

    for (var path in data["paths"]) {
      di.paths.add(RoutePath.fromMap(path));
    }
    return di;
  }

  bool isValid() {
    return this.location > 0 &&
        this.subLocation > 0 &&
        this.time > 0 &&
        this.errorCode == 0;
  }

  LocationPoint getLocationPoint() {
    return this.isValid()
        ? LocationPoint.fromData(
            this.location, this.subLocation, this.x, this.y)
        : null;
  }

  GlobalPoint getGlobalPoint() {
    return this.isValid()
        ? GlobalPoint.fromValue(this.latitude, this.longitude)
        : null;
  }

  bool inZoneInId(int id) {
    for (int i = 0; i < this.zones.length; ++i) {
      if ((this.zones[i]).id == id) {
        return true;
      }
    }

    return false;
  }

  bool inZoneInAlias(String alias) {
    for (int i = 0; i < this.zones.length; ++i) {
      if ((this.zones[i]).alias == alias) {
        return true;
      }
    }

    return false;
  }
}

==> navigine_sdk-1.1.2.tar.gz: lib/models/device_info.dart <==
part of navigine_sdk;

class DeviceInfo {
  String id = "";
  int location = 0;
  int subLocation = 0;
  int time = 0;
  double x = 0.0;
  double y = 0.0;
  double r = 0.0;
  double azimuth = 0.0;
  double stepLength = 0.0;
  int stepCount = 0;
  int errorCode = 0;
  List<RoutePath> paths = [];
  List<Zone> zones = [];
  double latitude = 0;
  double longitude = 0;

  static DeviceInfo fromMap(data) {
    DeviceInfo di = DeviceInfo();
    di.azimuth = data["azimuth"] as double;
    di.errorCode = data["errorCode"] as int;
    di.id = data["id"] as String;
    di.location = data["location"] as int;
    di.r = data["r"] as double;
    di.stepCount = data["stepCount"] as int;
    di.subLocation = data["subLocation"] as int;
    di.stepLength = data["stepLength"] as double;
    di.time = data["time"] as int;
    di.x = data["x"] as double;
    di.y = data["y"] as double;

    for (var zone in data["zones"]) {
      di.zones.add(Zone.fromMap(zone));
    }

    for (var path in data["paths"]) {
      di.paths.add(RoutePath.fromMap(path));
    }
    return di;
  }

  bool isValid() {
    return this.location > 0 &&
        this.subLocation > 0 &&
        this.time > 0 &&
        this.errorCode == 0;
  }

  LocationPoint? getLocationPoint() {
    return this.isValid()
        ? LocationPoint.fromData(
            this.location, this.subLocation, this.x, this.y)
        : null;
  }

  GlobalPoint? getGlobalPoint() {
    return this.isValid()
        ? GlobalPoint.fromValue(this.latitude, this.longitude)
        : null;
  }

  bool inZoneInId(int id) {
    for (int i = 0; i < this.zones.length; ++i) {
      if ((this.zones[i]).id == id) {
        return true;
      }
    }

    return false;
  }

  bool inZoneInAlias(String alias) {
    for (int i = 0; i < this.zones.length; ++i) {
      if ((this.zones[i]).alias == alias) {
        return true;
      }
    }

    return false;
  }
}
